==> open-cluster-management-observability-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/MultiClusterObservabilitySpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MultiClusterObservabilitySpecBuilder extends MultiClusterObservabilitySpecFluent<MultiClusterObservabilitySpecBuilder> implements VisitableBuilder<MultiClusterObservabilitySpec,MultiClusterObservabilitySpecBuilder>{
  public MultiClusterObservabilitySpecBuilder() {
    this(false);
  }
  public MultiClusterObservabilitySpecBuilder(Boolean validationEnabled) {
    this(new MultiClusterObservabilitySpec(), validationEnabled);
  }
  public MultiClusterObservabilitySpecBuilder(MultiClusterObservabilitySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MultiClusterObservabilitySpecBuilder(MultiClusterObservabilitySpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MultiClusterObservabilitySpec(), validationEnabled);
  }
  public MultiClusterObservabilitySpecBuilder(MultiClusterObservabilitySpecFluent<?> fluent,MultiClusterObservabilitySpec instance) {
    this(fluent, instance, false);
  }
  public MultiClusterObservabilitySpecBuilder(MultiClusterObservabilitySpecFluent<?> fluent,MultiClusterObservabilitySpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MultiClusterObservabilitySpec());

    if (instance != null) {
      fluent.withAdvanced(instance.getAdvanced());
      fluent.withEnableDownsampling(instance.getEnableDownsampling());
      fluent.withImagePullPolicy(instance.getImagePullPolicy());
      fluent.withImagePullSecret(instance.getImagePullSecret());
      fluent.withNodeSelector(instance.getNodeSelector());
      fluent.withObservabilityAddonSpec(instance.getObservabilityAddonSpec());
      fluent.withStorageConfig(instance.getStorageConfig());
      fluent.withTolerations(instance.getTolerations());
      fluent.withAdvanced(instance.getAdvanced());
      fluent.withEnableDownsampling(instance.getEnableDownsampling());
      fluent.withImagePullPolicy(instance.getImagePullPolicy());
      fluent.withImagePullSecret(instance.getImagePullSecret());
      fluent.withNodeSelector(instance.getNodeSelector());
      fluent.withObservabilityAddonSpec(instance.getObservabilityAddonSpec());
      fluent.withStorageConfig(instance.getStorageConfig());
      fluent.withTolerations(instance.getTolerations());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MultiClusterObservabilitySpecBuilder(MultiClusterObservabilitySpec instance) {
    this(instance,false);
  }
  public MultiClusterObservabilitySpecBuilder(MultiClusterObservabilitySpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MultiClusterObservabilitySpec());

    if (instance != null) {
      this.withAdvanced(instance.getAdvanced());
      this.withEnableDownsampling(instance.getEnableDownsampling());
      this.withImagePullPolicy(instance.getImagePullPolicy());
      this.withImagePullSecret(instance.getImagePullSecret());
      this.withNodeSelector(instance.getNodeSelector());
      this.withObservabilityAddonSpec(instance.getObservabilityAddonSpec());
      this.withStorageConfig(instance.getStorageConfig());
      this.withTolerations(instance.getTolerations());
      this.withAdvanced(instance.getAdvanced());
      this.withEnableDownsampling(instance.getEnableDownsampling());
      this.withImagePullPolicy(instance.getImagePullPolicy());
      this.withImagePullSecret(instance.getImagePullSecret());
      this.withNodeSelector(instance.getNodeSelector());
      this.withObservabilityAddonSpec(instance.getObservabilityAddonSpec());
      this.withStorageConfig(instance.getStorageConfig());
      this.withTolerations(instance.getTolerations());
    }
    this.validationEnabled = validationEnabled; 
  }
  MultiClusterObservabilitySpecFluent<?> fluent;
  Boolean validationEnabled;
  public MultiClusterObservabilitySpec build() {
    MultiClusterObservabilitySpec buildable = new MultiClusterObservabilitySpec(fluent.buildAdvanced(),fluent.getEnableDownsampling(),fluent.getImagePullPolicy(),fluent.getImagePullSecret(),fluent.getNodeSelector(),fluent.buildObservabilityAddonSpec(),fluent.buildStorageConfig(),fluent.getTolerations());
    return buildable;
  }
  
}

==> open-cluster-management-observability-model-6.12.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/MultiClusterObservabilitySpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class MultiClusterObservabilitySpecBuilder extends MultiClusterObservabilitySpecFluent<MultiClusterObservabilitySpecBuilder> implements VisitableBuilder<MultiClusterObservabilitySpec,MultiClusterObservabilitySpecBuilder>{
  public MultiClusterObservabilitySpecBuilder() {
    this(new MultiClusterObservabilitySpec());
  }
  
  public MultiClusterObservabilitySpecBuilder(MultiClusterObservabilitySpecFluent<?> fluent) {
    this(fluent, new MultiClusterObservabilitySpec());
  }
  
  public MultiClusterObservabilitySpecBuilder(MultiClusterObservabilitySpecFluent<?> fluent,MultiClusterObservabilitySpec instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public MultiClusterObservabilitySpecBuilder(MultiClusterObservabilitySpec instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  MultiClusterObservabilitySpecFluent<?> fluent;
  
  public MultiClusterObservabilitySpec build() {
    MultiClusterObservabilitySpec buildable = new MultiClusterObservabilitySpec(fluent.buildAdvanced(),fluent.getEnableDownsampling(),fluent.getImagePullPolicy(),fluent.getImagePullSecret(),fluent.getNodeSelector(),fluent.buildObservabilityAddonSpec(),fluent.buildStorageConfig(),fluent.getTolerations());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}
